==> igniteui-angular-charts-17.2.1.tgz: package/esm2015/lib/MovingAverageConvergenceDivergenceIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { MovingAverageConvergenceDivergenceIndicatorStrategy } from "./MovingAverageConvergenceDivergenceIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
import { Brush } from "igniteui-angular-core";
/**
 * @hidden
 */
export let MovingAverageConvergenceDivergenceIndicator = /*@__PURE__*/ (() => {
    class MovingAverageConvergenceDivergenceIndicator extends StrategyBasedIndicator {
        constructor() {
            super();
            this.trendLineBrush = ((() => {
                let $ret = new Brush();
                $ret.fill = "#565656";
                return $ret;
            })());
            this.trendLineType = 10;
            this.trendLinePeriod = 9;
        }
        bg() {
            return new MovingAverageConvergenceDivergenceIndicator();
        }
        get_x6() {
            return 1;
        }
        get_yz() {
            return new MovingAverageConvergenceDivergenceIndicatorStrategy();
        }
        get yz() {
            return this.get_yz();
        }
        get_zc() {
            return MovingAverageConvergenceDivergenceIndicator.$;
        }
        get zc() {
            return this.get_zc();
        }
        get shortPeriod() {
            return typeGetValue(this.c(MovingAverageConvergenceDivergenceIndicator.zn));
        }
        set shortPeriod(a) {
            this.h(MovingAverageConvergenceDivergenceIndicator.zn, a);
        }
        y7() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(MovingAverageConvergenceDivergenceIndicator.zm));
        }
        set longPeriod(a) {
            this.h(MovingAverageConvergenceDivergenceIndicator.zm, a);
        }
        y4() {
            return this.longPeriod;
        }
        get signalPeriod() {
            return typeGetValue(this.c(MovingAverageConvergenceDivergenceIndicator.zo));
        }
        set signalPeriod(a) {
            this.h(MovingAverageConvergenceDivergenceIndicator.zo, a);
        }
        yf() {
            return this.signalPeriod;
        }
    }
    MovingAverageConvergenceDivergenceIndicator.$t = markType(MovingAverageConvergenceDivergenceIndicator, 'MovingAverageConvergenceDivergenceIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    MovingAverageConvergenceDivergenceIndicator.zn = StrategyBasedIndicator.zj(10, MovingAverageConvergenceDivergenceIndicator.$);
    MovingAverageConvergenceDivergenceIndicator.zm = StrategyBasedIndicator.zf(30, MovingAverageConvergenceDivergenceIndicator.$);
    MovingAverageConvergenceDivergenceIndicator.zo = StrategyBasedIndicator.zi(9, MovingAverageConvergenceDivergenceIndicator.$, "SignalPeriod");
    return MovingAverageConvergenceDivergenceIndicator;
})();

==> igniteui-angular-charts-17.3.0.tgz: package/esm2015/lib/MovingAverageConvergenceDivergenceIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { MovingAverageConvergenceDivergenceIndicatorStrategy } from "./MovingAverageConvergenceDivergenceIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
import { Brush } from "igniteui-angular-core";
/**
 * @hidden
 */
export let MovingAverageConvergenceDivergenceIndicator = /*@__PURE__*/ (() => {
    class MovingAverageConvergenceDivergenceIndicator extends StrategyBasedIndicator {
        constructor() {
            super();
            this.trendLineBrush = ((() => {
                let $ret = new Brush();
                $ret.fill = "#565656";
                return $ret;
            })());
            this.trendLineType = 10;
            this.trendLinePeriod = 9;
        }
        bc() {
            return new MovingAverageConvergenceDivergenceIndicator();
        }
        get_x7() {
            return 1;
        }
        get_y0() {
            return new MovingAverageConvergenceDivergenceIndicatorStrategy();
        }
        get y0() {
            return this.get_y0();
        }
        get_zd() {
            return MovingAverageConvergenceDivergenceIndicator.$;
        }
        get zd() {
            return this.get_zd();
        }
        get shortPeriod() {
            return typeGetValue(this.c(MovingAverageConvergenceDivergenceIndicator.zo));
        }
        set shortPeriod(a) {
            this.h(MovingAverageConvergenceDivergenceIndicator.zo, a);
        }
        y8() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(MovingAverageConvergenceDivergenceIndicator.zn));
        }
        set longPeriod(a) {
            this.h(MovingAverageConvergenceDivergenceIndicator.zn, a);
        }
        y5() {
            return this.longPeriod;
        }
        get signalPeriod() {
            return typeGetValue(this.c(MovingAverageConvergenceDivergenceIndicator.zp));
        }
        set signalPeriod(a) {
            this.h(MovingAverageConvergenceDivergenceIndicator.zp, a);
        }
        yg() {
            return this.signalPeriod;
        }
    }
    MovingAverageConvergenceDivergenceIndicator.$t = markType(MovingAverageConvergenceDivergenceIndicator, 'MovingAverageConvergenceDivergenceIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    MovingAverageConvergenceDivergenceIndicator.zo = StrategyBasedIndicator.zk(10, MovingAverageConvergenceDivergenceIndicator.$);
    MovingAverageConvergenceDivergenceIndicator.zn = StrategyBasedIndicator.zg(30, MovingAverageConvergenceDivergenceIndicator.$);
    MovingAverageConvergenceDivergenceIndicator.zp = StrategyBasedIndicator.zj(9, MovingAverageConvergenceDivergenceIndicator.$, "SignalPeriod");
    return MovingAverageConvergenceDivergenceIndicator;
})();
